@@ -30,6 +30,7 @@ const GdPrivate = imports.gi.GdPrivate;
 const Gdk = imports.gi.Gdk;
 const GData = imports.gi.GData;
 const GLib = imports.gi.GLib;
+const GnomeDesktop = imports.gi.GnomeDesktop;
 const Gtk = imports.gi.Gtk;
 const Zpj = imports.gi.Zpj;
 const _ = imports.gettext.gettext;
@@ -362,6 +363,10 @@ const DocCommon = new Lang.Class({
         }
     },
 
+    load: function() {
+        log('Error: DocCommon implementations must override load');
+    },
+
     canEdit: function() {
         log('Error: DocCommon implementations must override canEdit');
     },
@@ -630,7 +635,7 @@ const DocCommon = new Lang.Class({
             }));
     },
 
-    open: function(screen, timestamp) {
+    open: function(parent, timestamp) {
         if (!this.defaultAppName)
             return;
 
@@ -640,7 +645,7 @@ const DocCommon = new Lang.Class({
             if (this.defaultApp)
                 this.defaultApp.launch_uris( [ this.uri ], null);
             else
-                Gtk.show_uri(screen, this.uri, timestamp);
+                Gtk.show_uri_on_window(parent, this.uri, timestamp);
         } catch (e) {
             logError(e, 'Unable to show URI ' + this.uri);
         }
@@ -914,12 +919,10 @@ const GoogleDocument = new Lang.Class({
                                                              authorization_domain: authorizationDomain,
                                                              download_uri: uri });
 
-                let checksum = new GLib.Checksum(GLib.ChecksumType.MD5);
-                checksum.update(this.uri, -1);
-                let dirPath = GLib.build_filenamev([GLib.get_user_cache_dir(), "thumbnails", "normal"]);
+                let path = GnomeDesktop.desktop_thumbnail_path_for_uri (this.uri,
+                                                                        GnomeDesktop.DesktopThumbnailSize.NORMAL);
+                let dirPath = GLib.path_get_dirname(path);
                 GLib.mkdir_with_parents(dirPath, 448);
-                let basename = checksum.get_string() + '.png';
-                let path = GLib.build_filenamev([dirPath, basename])
 
                 let downloadFile = Gio.File.new_for_path(path);
                 downloadFile.replace_async
@@ -1055,6 +1058,8 @@ const OwncloudDocument = new Lang.Class({
     }
 });
 
+const SKYDRIVE_PREFIX = 'windows-live:skydrive:';
+
 const SkydriveDocument = new Lang.Class({
     Name: 'SkydriveDocument',
     Extends: DocCommon,
@@ -1074,9 +1079,7 @@ const SkydriveDocument = new Lang.Class({
 
         let authorizer = new Zpj.GoaAuthorizer({ goa_object: source.object });
         let service = new Zpj.Skydrive({ authorizer: authorizer });
-
-        const zpj_prefix = "windows-live:skydrive:";
-        let zpj_id = this.identifier.substring(zpj_prefix.length);
+        let zpj_id = this.identifier.substring(SKYDRIVE_PREFIX.length);
 
         service.query_info_from_id_async
             (zpj_id, cancellable,
@@ -1227,7 +1230,7 @@ const DocumentManager = new Lang.Class({
 
     _identifierIsSkydrive: function(identifier) {
         return (identifier &&
-                (identifier.indexOf('windows-live:skydrive:') != -1));
+                (identifier.indexOf(SKYDRIVE_PREFIX) != -1));
     },
 
     createDocumentFromCursor: function(cursor) {
@@ -1354,6 +1357,8 @@ const DocumentManager = new Lang.Class({
             return;
         }
 
+        logError(error, 'Unable to load document');
+
         // Translators: %s is the title of a document
         let message = _("Oops! Unable to load “%s”").format(doc.name);
         let exception = this._humanizeError(error);
@@ -1384,6 +1389,15 @@ const DocumentManager = new Lang.Class({
         Application.modeController.setWindowMode(windowMode);
     },
 
+    _loadActiveItem: function(passwd) {
+        let doc = this.getActiveItem();
+
+        this._loaderCancellable = new Gio.Cancellable();
+        this._requestPreview(doc);
+        this.emit('load-started', doc);
+        doc.load(passwd, this._loaderCancellable, Lang.bind(this, this._onDocumentLoaded));
+    },
+
     reloadActiveItem: function(passwd) {
         let doc = this.getActiveItem();
 
@@ -1396,10 +1410,7 @@ const DocumentManager = new Lang.Class({
         // cleanup any state we have for previously loaded model
         this._clearActiveDocModel();
 
-        this._loaderCancellable = new Gio.Cancellable();
-        this._requestPreview(doc);
-        this.emit('load-started', doc);
-        doc.load(passwd, this._loaderCancellable, Lang.bind(this, this._onDocumentLoaded));
+        this._loadActiveItem(passwd);
     },
 
     removeItemById: function(id) {
@@ -1455,10 +1466,7 @@ const DocumentManager = new Lang.Class({
             let recentManager = Gtk.RecentManager.get_default();
             recentManager.add_item(doc.uri);
 
-            this._loaderCancellable = new Gio.Cancellable();
-            this._requestPreview(doc);
-            this.emit('load-started', doc);
-            doc.load(null, this._loaderCancellable, Lang.bind(this, this._onDocumentLoaded));
+            this._loadActiveItem(null);
         }
 
         return retval;
