@@ -986,13 +986,17 @@ const SelectionToolbar = new Lang.Class({
     },
 
     _onToolbarOpen: function(widget) {
+        let selection = Application.selectionController.getSelection();
         this._overview.getAction('selection-mode').change_state(GLib.Variant.new('b', false));
 
-        let selection = Application.selectionController.getSelection();
         selection.forEach(Lang.bind(this,
             function(urn) {
                 let doc = Application.documentManager.getItemById(urn);
-                doc.open(widget.get_screen(), Gtk.get_current_event_time());
+                let toplevel = this.get_toplevel();
+                if (!toplevel.is_toplevel())
+                    throw(new Error('Code should not be reached'));
+
+                doc.open(toplevel, Gtk.get_current_event_time());
             }));
     },
 
